==> client-sdk-react-0.59.0.tgz: package/src/components/common/SelectButton.tsx <==
import React, { useState } from 'react'
import { Popover } from 'react-tiny-popover'
import './SelectButton.scss'

export interface MenuItem {
  label: string
}

export const SelectButton: React.FC<{
  menuItems: MenuItem[]
  onMenuItemSelected?: (item: MenuItem) => void
  disabled?: boolean
  className?: string
  buttonLabel?: string
}> = ({ menuItems, onMenuItemSelected, disabled, className, buttonLabel }) => {
  const [popoverVisible, setPopoverVisible] = useState(false)

  const handleMenuItemClick = (item: MenuItem) => {
    setPopoverVisible(false)
    onMenuItemSelected && onMenuItemSelected(item)
  }

  const menu = (
    <div className='select-button__popover-container'>
      <ul className='select-button__popover-list'>
        {menuItems?.map((item, i) => {
          return (
            <li className='select-button__popover-item' key={i} onClick={() => handleMenuItemClick(item)}>
              {item.label}
            </li>
          )
        })}
      </ul>
    </div>
  )

  return (
    <div className={className}>
      <Popover
        isOpen={popoverVisible}
        positions={['top']}
        content={menu}
        onClickOutside={() => setPopoverVisible(false)}
      >
        <div className='select-button__button-container'>
          <button
            disabled={disabled}
            className='select-button__button'
            onClick={() => setPopoverVisible(!popoverVisible)}
            aria-label={buttonLabel}
          >
            <div className='select-button__button-icon' />
          </button>
        </div>
      </Popover>
    </div>
  )
}

==> client-sdk-react-1.2.1.tgz: package/src/components/common/SelectButton.tsx <==
import React, { useState } from 'react'
import { Popover } from 'react-tiny-popover'
import './SelectButton.scss'
import classNames from "classnames";

export interface MenuItem {
  label: string
}

export const SelectButton: React.FC<{
  menuItems: MenuItem[]
  onMenuItemSelected?: (item: MenuItem) => void
  disabled?: boolean
  className?: string
  buttonLabel?: string
}> = ({ menuItems, onMenuItemSelected, disabled, className, buttonLabel }) => {
  const [popoverVisible, setPopoverVisible] = useState(false)

  const handleMenuItemClick = (item: MenuItem) => {
    setPopoverVisible(false)
    onMenuItemSelected && onMenuItemSelected(item)
  }

  const menu = (
    <div className='select-button__popover-container'>
      <ul className='select-button__popover-list'>
        {menuItems?.map((item, i) => {
          return (
            <li className='select-button__popover-item' key={i} onClick={() => handleMenuItemClick(item)}>
              {item.label}
            </li>
          )
        })}
      </ul>
    </div>
  )

  return (
    <div className={className}>
      <Popover
        isOpen={popoverVisible}
        positions={['top']}
        content={menu}
        onClickOutside={() => setPopoverVisible(false)}
      >
        <div className={classNames('select-button__button-container', {
            'disabled': disabled
        })}>
          <button
            disabled={disabled}
            className='select-button__button'
            onClick={() => setPopoverVisible(!popoverVisible)}
            aria-label={buttonLabel}
          >
            <div className='select-button__button-icon' />
          </button>
        </div>
      </Popover>
    </div>
  )
}
